@@ -613,7 +613,7 @@ void AlarmDialog::showEvent(QShowEvent *event)
     // which happens when a notification appears and the dialog was already
     // up.
     KWindowSystem::setOnAllDesktops(winId(), true);
-    KWindowSystem::unminimizeWindow(winId(), false);
+    KWindowSystem::unminimizeWindow(winId());
     KWindowSystem::setState(winId(), NET::KeepAbove | NET::DemandsAttention);
 }
 
@@ -1058,7 +1058,7 @@ bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &inc
         auto winInfo = KWindowInfo(window, NET::WMDesktop);
         int desktop = winInfo.desktop();
         if (KWindowSystem::currentDesktop() == desktop) {
-            KWindowSystem::minimizeWindow(winId(), false);
+            KWindowSystem::minimizeWindow(winId());
         } else {
             KWindowSystem::setCurrentDesktop(desktop);
         }
@@ -1069,7 +1069,7 @@ bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &inc
     QDBusReply<int> reply = korganizerObj.call(QStringLiteral("winId"));
     if (reply.isValid()) {
         int window = reply;
-        KWindowSystem::minimizeWindow(winId(), false);
+        KWindowSystem::minimizeWindow(winId());
         KWindowSystem::allowExternalProcessWindowActivation();
         KWindowSystem::activateWindow(reinterpret_cast<WId>(window));
     }
